********************
bong: a simple timer
********************

.. image:: https://travis-ci.org/prophile/bong.svg
    :target: https://travis-ci.org/prophile/bong

.. image:: https://pypip.in/version/bong/badge.svg
    :target: https://pypi.python.org/pypi/bong/
    :alt: Latest Version

bong (pronounced as an impression of Big Ben) is a simple tool to count down
a fixed period, then display a notification.

